@@ -29,6 +29,24 @@ use strict;
 
 package Attachment;
 
+# Use the template toolkit (http://www.template-toolkit.org/) to generate
+# the user interface (HTML pages and mail messages) using templates in the
+# "templates/" subdirectory.
+use Template;
+
+# This is the global template object that gets used one or more times by
+# the script when it needs to process a template and return the results.
+# Configuration parameters can be specified here that apply to all templates
+# processed in this file.
+my $template = Template->new(
+  {
+    # Colon-separated list of directories containing templates.
+    INCLUDE_PATH => 'template/custom:/usr/share/bugzilla/lib/template/default' ,
+    # Allow templates to be specified with relative paths.
+    RELATIVE => 1 
+  }
+);
+
 # This module requires that its caller have said "require CGI.pl" to import
 # relevant functions from that script and its companion globals.pl.
 
