@@ -25,6 +25,9 @@ use diagnostics;
 use strict;
 
 use DBI;
+
+use lib '/usr/share/bugzilla/lib';
+
 use RelationSet;
 use vars qw($unconfirmedstate $legal_keywords);
 require "globals.pl";
@@ -326,7 +329,9 @@ sub XML_Header {
 
   my $xml;
   $xml = "<?xml version=\"1.0\" standalone=\"yes\"?>\n";
-  $xml .= "<!DOCTYPE bugzilla SYSTEM \"$urlbase";
+  my $no_cgi_urlbase = $urlbase;
+  $no_cgi_urlbase =~ s{/cgi-bin}{};
+  $xml .= "<!DOCTYPE bugzilla SYSTEM \"$no_cgi_urlbase";
   if (! ($urlbase =~ /.+\/$/)) {
     $xml .= "/";
   }
