@@ -103,8 +103,8 @@ sub generateSqlDeltas {
   if ( $#insertList > -1 ) {
     $sqlInsert = "INSERT INTO $table ($invariantName, $columnName) VALUES " .
       join (",", 
-	    map ( "($invariantValue, $_)" , @insertList ) 
-	   );
+            map ( "($invariantValue, $_)" , @insertList ) 
+           );
   }
      
   # construct the delete list by seeing which relations exist in the
@@ -248,7 +248,7 @@ sub toArrayOfStrings {
     push @result, &::DBID_to_name($i);
   }
 
-  return sort(@result);
+  return sort { lc($a) cmp lc($b) } @result;
 }  
 
 # return this set in string form (comma-separated and sorted)
