@@ -35,6 +35,8 @@
 use diagnostics;
 use strict;
 
+my $var_lib='/var/lib/bugzilla';
+
 # Shut up misguided -w warnings about "used only once".  For some reason,
 # "use vars" chokes on me when I try it here.
 
@@ -57,7 +59,7 @@ sub WriteParams {
 
     require File::Temp;
     my ($fh, $tmpname) = File::Temp::tempfile("params.XXXXX",
-                                              DIR=>'data');
+                                              DIR=>"$var_lib/data");
     my $v = $::param{'version'};
     delete $::param{'version'};  # Don't write the version number out to
                                 # the params file.
@@ -65,8 +67,8 @@ sub WriteParams {
     $::param{'version'} = $v;
     print $fh "1;\n";
     close $fh;
-    rename $tmpname, "data/params" || die "Can't rename $tmpname to data/params";
-    ChmodDataFile('data/params', 0666);
+    rename $tmpname, "$var_lib/data/params" || die "Can't rename $tmpname to $var_lib/data/params";
+    ChmodDataFile("$var_lib/data/params", 0644);
 }
     
 
@@ -135,7 +137,7 @@ DefParam("maintainer",
 DefParam("urlbase",
          "The URL that is the common initial leading part of all Bugzilla URLs.",
          "t",
-         "http://cvs-mirror.mozilla.org/webtools/bugzilla/",
+         "http://localhost/cgi-bin/bugzilla/",
          \&check_urlbase);
 
 sub check_urlbase {
@@ -444,7 +446,7 @@ sub check_webdotbase {
             return "The file path \"$value\" is not a valid executable.  Please specify the complete file path to 'dot' if you intend to generate graphs locally.";
         }
         # Check .htaccess allows access to generated images
-        if(-e "data/webdot/.htaccess") {
+        if(-e "$var_lib/data/webdot/.htaccess") {
             open HTACCESS, "data/webdot/.htaccess";
             if(! grep(/ \\\.png\$/,<HTACCESS>)) {
                 print "Dependency graph images are not accessible.\nAssuming that you have not modified the file, delete data/webdot/.htaccess and re-run checksetup.pl to rectify.\n";
@@ -454,7 +456,6 @@ sub check_webdotbase {
     }
     return "";
 }
-
 DefParam("expectbigqueries",
          "If this is on, then we will tell mysql to <tt>set option SQL_BIG_TABLES=1</tt> before doing queries on bugs.  This will be a little slower, but one will not get the error <tt>The table ### is full</tt> for big queries that require a big temporary table.",
          "b",
