@@ -1,4 +1,4 @@
-#!/usr/bonsaitools/bin/perl -w
+#!/usr/bonsaitools/bin/perl -wT
 # -*- Mode: perl; indent-tabs-mode: nil -*-
 #
 # The contents of this file are subject to the Mozilla Public
@@ -23,6 +23,9 @@
 
 use diagnostics;
 use strict;
+
+use lib '/usr/share/bugzilla/lib';
+
 use Bug;
 require "CGI.pl";
 $::lockcount = 0;
@@ -34,11 +37,12 @@ unless ( Param("move-enabled") ) {
 }
 
 ConnectToDatabase();
+confirm_login();
 
 sub Log {
     my ($str) = (@_);
     Lock();
-    open(FID, ">>data/maillog") || die "Can't write to data/maillog";
+    open(FID, ">>/var/lib/bugzilla/data/maillog") || die "Can't write to /var/lib/bugzilla/data/maillog";
     print FID time2str("%D %H:%M", time()) . ": $str\n";
     close FID;
     Unlock();
@@ -47,13 +51,13 @@ sub Log {
 sub Lock {
     if ($::lockcount <= 0) {
         $::lockcount = 0;
-        open(LOCKFID, ">>data/maillock") || die "Can't open lockfile.";
+        open(LOCKFID, ">>/var/lib/bugzilla/data/maillock") || die "Can't open /var/lib/bugzilla/data/maillock: $!";
         my $val = flock(LOCKFID,2);
         if (!$val) { # '2' is magic 'exclusive lock' const.
             print "Content-type: text/html\n\n";
             print "Lock failed: $val\n";
         }
-        chmod 0666, "data/maillock";
+        chmod 0644, "/var/lib/bugzilla/data/maillock";
     }
     $::lockcount++;
 }
@@ -77,7 +81,6 @@ if ( !defined $::FORM{'buglist'} ) {
   exit;
 }
 
-confirm_login();
 my $exporter = $::COOKIE{"Bugzilla_login"};
 my $movers = Param("movers");
 $movers =~ s/\w?,\w?/|/g;
@@ -114,7 +117,11 @@ foreach my $id (split(/:/, $::FORM{'buglist'})) {
     SendSQL("UPDATE bugs SET bug_status =\"RESOLVED\" where bug_id=\"$id\"");
     SendSQL("UPDATE bugs SET resolution =\"MOVED\" where bug_id=\"$id\"");
 
-    my $comment = "Bug moved to " . Param("move-to-url") . ".\n\n";
+    my $comment = "";
+    if (defined $::FORM{'comment'} && $::FORM{'comment'} !~ /^\s*$/) {
+        $comment .= $::FORM{'comment'} . "\n\n";
+    }
+    $comment .= "Bug moved to " . Param("move-to-url") . ".\n\n";
     $comment .= "If the move succeeded, $exporter will receive a mail\n";
     $comment .= "containing the number of the new bug in the other database.\n";
     $comment .= "If all went well,  please mark this bug verified, and paste\n";
@@ -123,7 +130,7 @@ foreach my $id (split(/:/, $::FORM{'buglist'})) {
         "($id,  $exporterid, now(), " . SqlQuote($comment) . ")");
 
     print "<P>Bug $id moved to " . Param("move-to-url") . ".<BR>\n";
-    system("./processmail", $id, $exporter);
+    system("/usr/share/bugzilla/lib/processmail", $id, $exporter);
   }
 }
 print "<P>\n";
@@ -143,7 +150,7 @@ $msg .= "Subject: Moving bug(s) $buglist\n\n";
 $msg .= $xml . "\n";
 
 open(SENDMAIL,
-  "|/usr/lib/sendmail -ODeliveryMode=background -t") ||
+  "|/usr/lib/sendmail -t -i") ||
     die "Can't open sendmail";
 print SENDMAIL $msg;
 close SENDMAIL;
