@@ -706,7 +706,7 @@ function QuickSearch (input)
     if (input == "") 
     {
         //once this _is_ on http://bugzilla.mozilla.org, it should just return;
-        go_to(bugzilla);
+        go_to("/bugzilla");
     } 
     else if (input.match(/^[0-9, ]*$/)) 
     {
