@@ -4,7 +4,7 @@ TEST_VERBOSE=0
 PART1='use Test::Harness qw(&runtests $verbose); $verbose='
 PART2='; runtests @ARGV;'
 for f in $*; do
-  if [ $f == "--verbose" ] ; then
+  if [ "$f" = "--verbose" ] ; then
     TEST_VERBOSE=1
   fi
 done
